==> icaatom-1.0.5.tgz: icaatom-1.0.5/apps/qubit/modules/informationobject/actions/treeViewComponent.class.php <==
<?php

/*
 * This file is part of Qubit Toolkit.
 *
 * Qubit Toolkit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * Qubit Toolkit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Qubit Toolkit.  If not, see <http://www.gnu.org/licenses/>.
 */

class InformationObjectTreeViewComponent extends sfComponent
{
  public function execute($request)
  {
    $this->informationObject = $request->getAttribute('informationObject');

    if (count($this->informationObjects) < 1)
    {
      return sfView::NONE;
    }

    $this->getResponse()->addJavaScript('/vendor/jquery/jquery');
    $this->getResponse()->addJavaScript('/sfDrupalPlugin/vendor/drupal/misc/drupal');
    $this->getResponse()->addJavaScript('qubit');
    $this->getResponse()->addJavaScript('/vendor/yui/yahoo-dom-event/yahoo-dom-event');
    $this->getResponse()->addJavaScript('/vendor/yui/treeview/treeview-min');
    $this->getResponse()->addJavaScript('treeView');
    $this->getResponse()->addStylesheet('yui/treeview/assets/skins/qubit/treeview-skin');

    $this->treeViewObjects = array();
    foreach ($this->informationObjects->orderBy('lft') as $informationObject)
    {
      $treeViewObject = array();
      $treeViewObject['label'] = (string) render_title($informationObject->getLabel(array('truncate' => 50)));
      $treeViewObject['href'] = $this->getController()->genUrl('informationobject/show?id='.$informationObject->getId());
      $treeViewObject['id'] = $informationObject->getId();
      $treeViewObject['parentId'] = $informationObject->getParentId();

      // TODO: Should be able to check equality of objects
      if ($informationObject->getId() == $this->informationObject->getId())
      {
        $treeViewObject['style'] = 'ygtvlabel currentTextNode';
      }

      $this->treeViewObjects[] = $treeViewObject;
    }

    $this->treeViewExpands = array();
    foreach ($this->informationObject->getAncestors() as $ancestor)
    {
      $this->treeViewExpands[$id = $ancestor->getId()] = $id;
    }
    $this->treeViewExpands[$id = $this->informationObject->getId()] = $id;
  }
}

==> icaatom-1.0.6.tgz: icaatom-1.0.6/apps/qubit/modules/informationobject/actions/treeViewComponent.class.php <==
<?php

/*
 * This file is part of Qubit Toolkit.
 *
 * Qubit Toolkit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * Qubit Toolkit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Qubit Toolkit.  If not, see <http://www.gnu.org/licenses/>.
 */

class InformationObjectTreeViewComponent extends sfComponent
{
  public function execute($request)
  {
    $this->informationObject = $request->getAttribute('informationObject');

    if (count($this->informationObjects) < 1)
    {
      return sfView::NONE;
    }

    $this->getResponse()->addJavaScript('/vendor/jquery/jquery');
    $this->getResponse()->addJavaScript('/sfDrupalPlugin/vendor/drupal/misc/drupal');
    $this->getResponse()->addJavaScript('qubit');
    $this->getResponse()->addJavaScript('/vendor/yui/yahoo-dom-event/yahoo-dom-event');
    $this->getResponse()->addJavaScript('/vendor/yui/treeview/treeview-min');
    $this->getResponse()->addJavaScript('treeView');
    $this->getResponse()->addStylesheet('yui/treeview/assets/skins/qubit/treeview-skin', 'first');

    $this->treeViewObjects = array();
    foreach ($this->informationObjects->orderBy('lft') as $informationObject)
    {
      $treeViewObject = array();
      $treeViewObject['label'] = (string) render_title($informationObject->getLabel(array('truncate' => 50)));
      $treeViewObject['href'] = $this->getController()->genUrl('informationobject/show?id='.$informationObject->getId());
      $treeViewObject['id'] = $informationObject->getId();
      $treeViewObject['parentId'] = $informationObject->getParentId();

      // TODO: Should be able to check equality of objects
      if ($informationObject->getId() == $this->informationObject->getId())
      {
        $treeViewObject['style'] = 'ygtvlabel currentTextNode';
      }

      $this->treeViewObjects[] = $treeViewObject;
    }

    $this->treeViewExpands = array();
    foreach ($this->informationObject->getAncestors() as $ancestor)
    {
      $this->treeViewExpands[$id = $ancestor->getId()] = $id;
    }
    $this->treeViewExpands[$id = $this->informationObject->getId()] = $id;
  }
}
